<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework 
 * @subpackage 	Markup\Inputs
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since		5.0.0
 * @version		5.3.1
 */

namespace WeCodeArt\Support\Markup\Inputs;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Support\Markup;
use WeCodeArt\Support\Markup\Inputs\Base;
use WeCodeArt\Support\Markup\Inputs\Basic;
use function WeCodeArt\Functions\get_prop;

/**
 * Standard Inputs Markup
 */
class Toggle extends Base {

    /**
     * Input's Vars.
     *
     * @since   5.0.0
     * @var     string
     */
    public $label_position  = 'none';
    public $with_messages   = false;

    /**
	 * Constructor 
	 */
    public function __construct( string $type = 'toggle', array $args = [] ) {
        $type               = get_prop( $args, 'type' );
        $this->type         = in_array( $type, [ 'radio', 'checkbox' ] ) ? $type : 'radio';
        $this->unique_id    = wp_unique_id( 'toggle-' );
        $this->label        = get_prop( $args, 'label', '' );
        $this->attrs        = get_prop( $args, 'attrs', [] );
        $this->messages     = get_prop( $args, 'messages', [] );
    }

	/**
	 * Create HTML Inputs
	 *
	 * @since	unknown
	 * @version	5.0.0
	 */
	public function content() {  
        wecodeart( 'markup' )::wrap( $this->type, [
            [
                'tag'   => 'div',
                'attrs' => [
                    'class' => implode( ' ', array_filter( [ 'form-check', $this->attrs['class'] ] ) ),
                ]
            ]
        ], 'wecodeart_input', [ $this->type, [
            'label'     => $this->label,
            '_label'    => 'after',
            'attrs'     => wp_parse_args( [
                'class' => 'form-check-input',
                'id'    => get_prop( $this->attrs, 'id', $this->unique_id )
            ], $this->attrs ),
            'messages'  => $this->messages
        ] ] ); 
    }
}