<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\CF7\Modules\Module
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since 		5.0.0
 * @version		5.3.1
 */

namespace WeCodeArt\Support\Plugins\CF7\Modules;

defined( 'ABSPATH' ) || exit;

use WeCodeArt\Singleton;

/**
 * Select Fields.
 */
class File extends Module {

	use Singleton;

	/**
	 * Module vars.
	 *
	 * @var mixed
	 */
	protected $name     = 'file';
	protected $fields   = [ 'file', 'file*' ];

	/**
	 * Return field HTML.
	 *
	 * @param   object $tag
     * 
	 * @return  string Rendered field output.
	 */
	public function get_html( $tag ) {
		if ( empty( $tag->name ) ) {
            return '';
        }
    
        $attrs = [];

        $validation_error   = wpcf7_get_validation_error( $tag->name );
        $class              = explode( ' ', wpcf7_form_controls_class( $tag->type, 'form-control' ) );
        
        if ( $validation_error ) {
            $class[] = 'wpcf7-not-valid';
            $attrs['aria-invalid'] 		= 'true';
            $attrs['aria-describedby'] 	= wpcf7_get_validation_error_reference( $tag->name );
        } else {
            $attrs['aria-invalid'] 		= 'false';
        }
    
        $attrs['type']      = 'file';
        $attrs['name']      = $tag->name;
        $attrs['size'] 		= $tag->get_size_option( '40' );
        $attrs['class']		= $tag->get_class_option( join( ' ', $class ) );
        $attrs['tabindex'] 	= $tag->get_option( 'tabindex', 'signed_int', true );
        $attrs['accept']    = wpcf7_acceptable_filetypes( $tag->get_option( 'filetypes' ), 'attr' );

        if( $tag->get_id_option() ) { 
            $attrs['id']    = $tag->get_id_option();
        }

        if ( $tag->is_required() ) {
            $attrs['required'] = true;
            $attrs['aria-required'] = 'true';
        }

        $html = wecodeart( 'markup' )::wrap( 'cf7-file-field', [ [
            'tag' 	=> 'span',
            'attrs' => [
                'class' => self::get_wrap_class( $tag )
            ]
        ] ], 'wecodeart_input', [ 'file', [
            'label' 	=> null,
            'attrs' 	=> $attrs,
            'messages' 	=> [
                'invalid' => $validation_error
            ]
        ] ], false );

        return $html;
	}

    /**
	 * Get Module args.
	 *
	 * @return array
	 */
	protected function get_args() {
		return [
			'name-attr'			=> true,
			'file-uploading'	=> true,
		];
	}
}
