<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\CF7\Modules\Module
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since 		5.0.0
 * @version		5.0.0
 */

namespace WeCodeArt\Support\Plugins\CF7\Modules;

defined( 'ABSPATH' ) || exit;

use WeCodeArt\Singleton;

/**
 * Quiz Fields.
 */
class Quiz extends Module {

	use Singleton;

	/**
	 * Module vars.
	 *
	 * @var mixed
	 */
	protected $name     = 'quiz';
	protected $fields   = 'quiz';

	/**
	 * Return field HTML.
	 *
	 * @param   object $tag
     * 
	 * @return  string Rendered field output.
	 */
	public function get_html( $tag ) {
		if ( empty( $tag->name ) ) {
            return '';
        }
    
        $validation_error = wpcf7_get_validation_error( $tag->name );
    
        $class      = explode( ' ', wpcf7_form_controls_class( $tag->type, 'form-control' ) );
        $class[]    = 'wpcf7-validates-as-number';
        
        if ( $validation_error ) {
            $class[] = 'wpcf7-not-valid';
            $attrs['aria-invalid']      = 'true';
            $attrs['aria-describedby']  = wpcf7_get_validation_error_reference( $tag->name );
        } else {
            $attrs['aria-invalid']      = 'false';
        }
    
        $attrs = [];
    
        $attrs['type'] = 'text';
        $attrs['name'] = $tag->name;
        $attrs['size'] = $tag->get_size_option( '40' );
        $attrs['maxlength'] = $tag->get_maxlength_option();
        $attrs['minlength'] = $tag->get_minlength_option();
    
        if ( $attrs['maxlength'] and $attrs['minlength'] and $attrs['maxlength'] < $attrs['minlength'] ) {
            unset( $attrs['maxlength'], $attrs['minlength'] );
        }
    
        $attrs['id']            = $tag->get_id_option();
        $attrs['class']         = $tag->get_class_option( join( ' ', $class ) );
        $attrs['tabindex']      = $tag->get_option( 'tabindex', 'signed_int', true );
        $attrs['autocomplete']  = 'off';
        $attrs['required']      = true;
        $attrs['aria-required'] = 'true';
    
        $pipes = $tag->pipes;
        
        if ( $pipes and ! $pipes->zero() ) {
            $pipe       = $pipes->random_pipe();
            $question   = $pipe->before;
            $answer     = $pipe->after;
        } else {
            $question   = '1+1=?';
            $answer     = '2';
        }
    
        $answer = wpcf7_canonicalize( $answer );

        $html = wecodeart( 'markup' )::wrap( 'cf7-quiz-field', [ [
            'tag' 	=> 'span',
            'attrs' => [
                'class' => self::get_wrap_class( $tag, 'input-group' )
            ]
        ] ], function() use ( $tag, $attrs, $question, $answer, $validation_error ) {
            ?>
            <span class="wpcf7-quiz-label input-group-text"><?php echo esc_html( $question ); ?></span>
            <?php
            
            wecodeart_input( 'hidden', [
                'attrs' => [
                    'id'    => false,
                    'class' => false,
                    'name'  => '_wpcf7_quiz_answer_' . $tag->name,
                    'value' => wp_hash( $answer, 'wpcf7_quiz' )
                ]
            ] );

            wecodeart_input( 'text', [
                'attrs' 	=> $attrs,
                'messages' 	=> [
                    'invalid' => $validation_error
                ]
            ] );

        }, [], false );

        return $html;
	}

    /**
	 * Get Module args.
	 *
	 * @return array
	 */
	protected function get_args() {
		return [
			'name-attr'     => true,
			'do-not-store'  => true,
			'not-for-mail'  => true,
		];
	}
}
